==> alwaysai-2.3.4.tgz: package/src/components/app/target/target-json-component.test.ts <==
import { CLI_USAGE_ERROR } from '@alwaysai/alwayscli';
import { runAndCatch } from '@carnesen/run-and-catch';
import {
  getTargetHardwareType,
  TargetJsonFile,
  TargetPathDefaultValue,
} from '../../../core/app';
import { targetJsonComponent } from './target-json-component';
import { targetPathPromptComponent } from './target-path-prompt-component';
import { targetProtocolPromptComponent } from './target-protocol-prompt-component';
import { DOCKER_IMAGE_ID_INITIAL_VALUE } from '../../../constants';
import { deviceSelectComponent, getTargetHostnameComponent } from '../../device';
import { checkForDockerComponent } from '../../docker';
import { ProjectJsonFile } from '../../../core/project';
import { AaiDevice } from '../../../infrastructure';
import { findOrWritePrivateKeyFileComponent } from '../../general';

jest.mock('../../../core/app');
const mockTargetJsonFileExists = jest.fn().mockReturnValue(false);
const mockTargetJsonFileReadTargetProtocolSafe = jest.fn();
const mockTargetJsonFileReadFieldSafe = jest.fn().mockReturnValue(undefined);
const mockTargetJsonFileWrite = jest.fn();
jest.mocked(TargetJsonFile as jest.Mock).mockReturnValue({
  exists: mockTargetJsonFileExists,
  readTargetProtocolSafe: mockTargetJsonFileReadTargetProtocolSafe,
  readFieldSafe: mockTargetJsonFileReadFieldSafe,
  write: mockTargetJsonFileWrite,
});

jest.mock('../../../core/project');
const projectId = '17';
const mockProjectJsonFileRead = jest.fn().mockReturnValue({
  project: { id: projectId },
});
jest.mocked(ProjectJsonFile as jest.Mock).mockReturnValue({
  read: mockProjectJsonFileRead,
});

jest.mock('./target-protocol-prompt-component');
jest.mock('../../docker');
jest.mock('../../device');
jest.mock('../../general');
jest.mock('./target-path-prompt-component');

describe(targetJsonComponent.name, () => {
  afterEach(() => {
    jest.clearAllMocks();
  });
  jest.setTimeout(30000);
  it('--yes without target protocol', async () => {
    const exception = await runAndCatch(targetJsonComponent, {
      yes: true,
    });
    expect(exception.code).toBe(CLI_USAGE_ERROR);
  });
  describe('native', () => {
    it('--yes via command line', async () => {
      await targetJsonComponent({
        yes: true,
        targetProtocol: 'native:',
      });

      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'native:',
      });
    });
    it('--yes via config file', async () => {
      mockTargetJsonFileExists.mockReturnValue(true);
      mockTargetJsonFileReadTargetProtocolSafe.mockReturnValue('native:');

      await targetJsonComponent({
        yes: true,
      });

      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'native:',
      });
    });
    it('native via prompt', async () => {
      // Test with previous value in config
      mockTargetJsonFileExists.mockReturnValue(true);
      mockTargetJsonFileReadTargetProtocolSafe.mockReturnValue('docker:');
      jest.mocked(targetProtocolPromptComponent).mockResolvedValue('native:');

      await targetJsonComponent({
        yes: false,
      });

      expect(jest.mocked(targetProtocolPromptComponent)).toBeCalledTimes(1);
      expect(jest.mocked(targetProtocolPromptComponent)).toBeCalledWith({
        prevTargetProtocol: 'docker:',
      });
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'native:',
      });
    });
  });
  describe('docker', () => {
    it('--yes via command line', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const targetHardware = 'jetson-jp4.6';
      jest.mocked(getTargetHardwareType).mockResolvedValue(targetHardware);

      await targetJsonComponent({
        yes: true,
        targetProtocol: 'docker:',
      });

      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledWith({});
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'docker:',
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
      });
    });
    it('--yes targetHardware via command line', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const targetHardware = 'jetson-jp4.6';

      await targetJsonComponent({
        yes: true,
        targetProtocol: 'docker:',
        targetHardware,
      });

      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(0);
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'docker:',
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
      });
    });
  });
  describe('ssh+docker', () => {
    it('--yes targetPath via command line', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const device = {
        uuid: 'C3P0',
        host_name: 'threepio',
        hardware_ids: '1234',
      } as AaiDevice;
      jest.mocked(deviceSelectComponent).mockResolvedValue(device);
      const targetHardware = 'amd64';
      jest.mocked(getTargetHostnameComponent).mockResolvedValue(device.host_name);
      jest.mocked(getTargetHardwareType).mockResolvedValue(targetHardware);
      const targetPath = 'tatooine';

      await targetJsonComponent({
        yes: true,
        targetProtocol: 'ssh+docker:',
        targetPath,
      });

      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledWith({
        yes: true,
      });
      expect(mockProjectJsonFileRead).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledWith({
        yes: true,
        deviceId: undefined,
      });
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledWith({
        yes: true,
        device,
      });
      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(checkForDockerComponent)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(jest.mocked(targetPathPromptComponent)).toBeCalledTimes(0);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'ssh+docker:',
        targetHostname: device.host_name,
        targetPath,
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
        deviceId: device.uuid,
      });
    });
    it('--yes targetHardware and targetPath via command line', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const device = {
        uuid: 'C3P0',
        host_name: 'threepio',
        hardware_ids: '1234',
      } as AaiDevice;
      jest.mocked(deviceSelectComponent).mockResolvedValue(device);
      jest.mocked(getTargetHostnameComponent).mockResolvedValue(device.host_name);
      const targetHardware = 'amd64';
      const targetPath = 'tatooine';

      await targetJsonComponent({
        yes: true,
        targetProtocol: 'ssh+docker:',
        targetHardware,
        targetPath,
      });

      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledWith({
        yes: true,
      });
      expect(mockProjectJsonFileRead).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledWith({
        yes: true,
        deviceId: undefined,
      });
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledWith({
        yes: true,
        device,
      });
      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(checkForDockerComponent)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(jest.mocked(targetPathPromptComponent)).toBeCalledTimes(0);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(0);
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'ssh+docker:',
        targetHostname: device.host_name,
        targetPath,
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
        deviceId: device.uuid,
      });
    });
    it('target path via prompt', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const device = {
        uuid: 'C3P0',
        host_name: 'threepio',
        hardware_ids: '1234',
      } as AaiDevice;
      jest.mocked(deviceSelectComponent).mockResolvedValue(device);
      jest.mocked(getTargetHostnameComponent).mockResolvedValue(device.host_name);
      const targetHardware = 'aarch64';
      jest.mocked(getTargetHardwareType).mockResolvedValue(targetHardware);
      const targetPath = 'tatooine';
      jest.mocked(targetPathPromptComponent).mockResolvedValue(targetPath);

      const targetHostname = 'deetoo';
      await targetJsonComponent({
        yes: false,
        targetProtocol: 'ssh+docker:',
        targetHostname,
      });

      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledWith({
        yes: false,
      });
      expect(mockProjectJsonFileRead).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledWith({
        yes: false,
        deviceId: undefined,
      });
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledWith({
        yes: false,
        device,
        targetHostname,
      });
      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(checkForDockerComponent)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(mockTargetJsonFileReadFieldSafe).toBeCalledTimes(1);
      expect(mockTargetJsonFileReadFieldSafe).toBeCalledWith({
        name: 'targetPath',
      });
      expect(jest.mocked(targetPathPromptComponent)).toBeCalledTimes(1);
      expect(jest.mocked(targetPathPromptComponent)).toBeCalledWith({
        targetHostname: device.host_name,
        targetPath: TargetPathDefaultValue(),
      });
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'ssh+docker:',
        targetHostname: device.host_name,
        targetPath,
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
        deviceId: device.uuid,
      });
    });
  });
});

==> alwaysai-2.4.0.tgz: package/src/components/app/target/target-json-component.test.ts <==
import { CLI_USAGE_ERROR } from '@alwaysai/alwayscli';
import { runAndCatch } from '@carnesen/run-and-catch';
import {
  getTargetHardwareType,
  TargetJsonFile,
  TargetPathDefaultValue,
} from '../../../core/app';
import { targetJsonComponent } from './target-json-component';
import { targetPathPromptComponent } from './target-path-prompt-component';
import { targetProtocolPromptComponent } from './target-protocol-prompt-component';
import { DOCKER_IMAGE_ID_INITIAL_VALUE } from '../../../constants';
import { deviceSelectComponent, getTargetHostnameComponent } from '../../device';
import { checkForDockerComponent } from '../../docker';
import { ProjectJsonFile } from '../../../core/project';
import { AaiDevice } from '../../../infrastructure';
import { findOrWritePrivateKeyFileComponent } from '../../general';

jest.mock('../../../core/app');
const mockTargetJsonFileExists = jest.fn().mockReturnValue(false);
const mockTargetJsonFileReadTargetProtocolSafe = jest.fn();
const mockTargetJsonFileReadFieldSafe = jest.fn().mockReturnValue(undefined);
const mockTargetJsonFileWrite = jest.fn();
jest.mocked(TargetJsonFile as jest.Mock).mockReturnValue({
  exists: mockTargetJsonFileExists,
  readTargetProtocolSafe: mockTargetJsonFileReadTargetProtocolSafe,
  readFieldSafe: mockTargetJsonFileReadFieldSafe,
  write: mockTargetJsonFileWrite,
});

jest.mock('../../../core/project');
const projectId = '17';
const mockProjectJsonFileRead = jest.fn().mockReturnValue({
  project: { id: projectId },
});
jest.mocked(ProjectJsonFile as jest.Mock).mockReturnValue({
  read: mockProjectJsonFileRead,
});

jest.mock('./target-protocol-prompt-component');
jest.mock('../../docker');
jest.mock('../../device');
jest.mock('../../general');
jest.mock('./target-path-prompt-component');

describe(targetJsonComponent.name, () => {
  afterEach(() => {
    jest.clearAllMocks();
  });
  jest.setTimeout(30000);
  it('--yes without target protocol', async () => {
    const exception = await runAndCatch(targetJsonComponent, {
      yes: true,
    });
    expect(exception.code).toBe(CLI_USAGE_ERROR);
  });
  describe('native', () => {
    it('--yes via command line', async () => {
      await targetJsonComponent({
        yes: true,
        targetProtocol: 'native:',
      });

      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'native:',
      });
    });
    it('--yes via config file', async () => {
      mockTargetJsonFileExists.mockReturnValue(true);
      mockTargetJsonFileReadTargetProtocolSafe.mockReturnValue('native:');

      await targetJsonComponent({
        yes: true,
      });

      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'native:',
      });
    });
    it('native via prompt', async () => {
      // Test with previous value in config
      mockTargetJsonFileExists.mockReturnValue(true);
      mockTargetJsonFileReadTargetProtocolSafe.mockReturnValue('docker:');
      jest.mocked(targetProtocolPromptComponent).mockResolvedValue('native:');

      await targetJsonComponent({
        yes: false,
      });

      expect(jest.mocked(targetProtocolPromptComponent)).toBeCalledTimes(1);
      expect(jest.mocked(targetProtocolPromptComponent)).toBeCalledWith({
        prevTargetProtocol: 'docker:',
      });
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'native:',
      });
    });
  });
  describe('docker', () => {
    it('--yes via command line', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const targetHardware = 'jetson-jp4.6';
      jest.mocked(getTargetHardwareType).mockResolvedValue(targetHardware);

      await targetJsonComponent({
        yes: true,
        targetProtocol: 'docker:',
      });

      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledWith({});
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'docker:',
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
      });
    });
    it('--yes targetHardware via command line', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const targetHardware = 'jetson-jp4.6';

      await targetJsonComponent({
        yes: true,
        targetProtocol: 'docker:',
        targetHardware,
      });

      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(0);
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'docker:',
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
      });
    });
  });
  describe('ssh+docker', () => {
    it('--yes targetPath via command line', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const device = {
        uuid: 'C3P0',
        host_name: 'threepio',
        hardware_ids: '1234',
      } as AaiDevice;
      jest.mocked(deviceSelectComponent).mockResolvedValue({ device, new: false });
      const targetHardware = 'amd64';
      jest.mocked(getTargetHostnameComponent).mockResolvedValue(device.host_name);
      jest.mocked(getTargetHardwareType).mockResolvedValue(targetHardware);
      const targetPath = 'tatooine';

      await targetJsonComponent({
        yes: true,
        targetProtocol: 'ssh+docker:',
        targetPath,
      });

      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledWith({
        yes: true,
      });
      expect(mockProjectJsonFileRead).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledWith({
        yes: true,
        deviceId: undefined,
      });
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledWith({
        yes: true,
        device,
      });
      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(checkForDockerComponent)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(jest.mocked(targetPathPromptComponent)).toBeCalledTimes(0);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'ssh+docker:',
        targetHostname: device.host_name,
        targetPath,
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
        deviceId: device.uuid,
      });
    });
    it('--yes targetHardware and targetPath via command line', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const device = {
        uuid: 'C3P0',
        host_name: 'threepio',
        hardware_ids: '1234',
      } as AaiDevice;
      jest.mocked(deviceSelectComponent).mockResolvedValue({ device, new: false });
      jest.mocked(getTargetHostnameComponent).mockResolvedValue(device.host_name);
      const targetHardware = 'amd64';
      const targetPath = 'tatooine';

      await targetJsonComponent({
        yes: true,
        targetProtocol: 'ssh+docker:',
        targetHardware,
        targetPath,
      });

      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledWith({
        yes: true,
      });
      expect(mockProjectJsonFileRead).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledWith({
        yes: true,
        deviceId: undefined,
      });
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledWith({
        yes: true,
        device,
      });
      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(checkForDockerComponent)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(jest.mocked(targetPathPromptComponent)).toBeCalledTimes(0);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(0);
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'ssh+docker:',
        targetHostname: device.host_name,
        targetPath,
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
        deviceId: device.uuid,
      });
    });
    it('target path via prompt', async () => {
      mockTargetJsonFileExists.mockReturnValue(false);
      const device = {
        uuid: 'C3P0',
        host_name: 'threepio',
        hardware_ids: '1234',
      } as AaiDevice;
      jest.mocked(deviceSelectComponent).mockResolvedValue({ device, new: false });
      jest.mocked(getTargetHostnameComponent).mockResolvedValue(device.host_name);
      const targetHardware = 'aarch64';
      jest.mocked(getTargetHardwareType).mockResolvedValue(targetHardware);
      const targetPath = 'tatooine';
      jest.mocked(targetPathPromptComponent).mockResolvedValue(targetPath);

      const targetHostname = 'deetoo';
      await targetJsonComponent({
        yes: false,
        targetProtocol: 'ssh+docker:',
        targetHostname,
      });

      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
      expect(jest.mocked(findOrWritePrivateKeyFileComponent)).toBeCalledWith({
        yes: false,
      });
      expect(mockProjectJsonFileRead).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledTimes(1);
      expect(jest.mocked(deviceSelectComponent)).toBeCalledWith({
        yes: false,
        deviceId: undefined,
      });
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHostnameComponent)).toBeCalledWith({
        yes: false,
        device,
        targetHostname,
      });
      expect(jest.mocked(checkForDockerComponent)).toBeCalledTimes(1);
      expect(jest.mocked(checkForDockerComponent)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(mockTargetJsonFileReadFieldSafe).toBeCalledTimes(1);
      expect(mockTargetJsonFileReadFieldSafe).toBeCalledWith({
        name: 'targetPath',
      });
      expect(jest.mocked(targetPathPromptComponent)).toBeCalledTimes(1);
      expect(jest.mocked(targetPathPromptComponent)).toBeCalledWith({
        targetHostname: device.host_name,
        targetPath: TargetPathDefaultValue(),
      });
      expect(jest.mocked(getTargetHardwareType)).toBeCalledTimes(1);
      expect(jest.mocked(getTargetHardwareType)).toBeCalledWith({
        targetHostname: device.host_name,
      });
      expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
      expect(mockTargetJsonFileWrite).toBeCalledWith({
        targetProtocol: 'ssh+docker:',
        targetHostname: device.host_name,
        targetPath,
        dockerImageId: DOCKER_IMAGE_ID_INITIAL_VALUE,
        targetHardware,
        deviceId: device.uuid,
      });
    });
  });
});
